#!/bin/bash

jarpath=""
ZENITY=""
architecture="sse4_1"

# Look for Offline Compiler jar file
function findjar() {
    if [ -f $1 ];
    then
        jarpath=$1
        return
    elif [ -f $INTELOCLSDKROOT/$1 ];
    then
        jarpath=$INTELOCLSDKROOT/$1
        return
    else
        patharray=$(echo $PATH | tr ":" "\n")  
        for x in $patharray 
        do
            if [ -f $x/$1 ];
            then
                jarpath=$x/$1
                return
            fi        
        done
    fi
}

# Launch error dialog if possible
function reporterror() {
    echo ERROR: $1
    if [ -x "$ZENITY" ]
    then
        $ZENITY --error --text "$1"
    fi
}

export INTELOCLSDKROOT=/usr/lib64/OpenCL/vendors/intel
export PATH=$INTELOCLSDKROOT:$PATH

# Look for zenity - GUI
if [ ! -s $DISPLAY ]; then 
    ZENITY=$(which zenity)
fi

iocfile="ioc.jar"

# This function updates the jarpath parameter
findjar $iocfile

if [ "$jarpath" != "" ];
then
    # Get architecture supported on this machine
	grep -q -e "^flags.*avx" /proc/cpuinfo
	retval = $?
	if [ $retval -eq 0 ];
	then
	    architecture="avx"
	else
	    grep -q -e "^flags.*sse4_2" /proc/cpuinfo
		retval = $?
	    if [ $retval -eq 0 ];
		then
		    architecture="sse4_2"
		fi
	fi

    # Add 32 bit support when available
    java -jar "$jarpath" x64 $architecture
	retval = $?
    if [ $retval -ne 0 ];
    then
        reporterror "could not find java runtime environment"
		exit -1
    fi
else
    reporterror "could not find $iocfile"
	exit -1
fi 


